CryptUtil class

Constructors

CryptUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decrypt(String encryptedBase64, String key, String iv) String
使用 AES-CBC 模式对密文进行解密(PKCS7 填充)
encrypt(String plainText, String key, String iv) String
使用 AES-CBC 模式对明文进行加密(PKCS7 填充)