CommodityItemEntity class
Constructors
- CommodityItemEntity({dynamic gracePeriod, String? prdId, int? firstDeductionType, dynamic ourReceiveAccount, dynamic remark, int? type, String? operator, int? firstPeriodType, int? payType, dynamic sdkVersionShow, dynamic imageUrl, String? ctime, String? iosProductId, dynamic signType, int? id, dynamic groupInfo, int? shelveStatus, String? group, double? unitPrice, dynamic customParamInfoList, int? paymentSchemes, String? prdName, String? utime, int? deductionTime, int? firstDeductionTime, String? commodityId, dynamic signingRedirectUrl, dynamic firstPeriod, dynamic customParam, dynamic getPriceUrl, int? timeliness, String? commodityProperty, dynamic prdMchMappingId, dynamic ourReceiveBank, String? commodityDesc, dynamic ourReceiveSubjectId, String? commodityName, String? desc, int? status, String? promotion, CommodityStoreEntity? storeEntity})
- CommodityItemEntity.fromJson(dynamic json)
Properties
- commodityDesc ↔ String?
-
getter/setter pair
- commodityId ↔ String?
-
getter/setter pair
- commodityName ↔ String?
-
getter/setter pair
- commodityProperty ↔ String?
-
getter/setter pair
- ctime ↔ String?
-
getter/setter pair
- customParam ↔ dynamic
-
getter/setter pair
- customParamInfoList ↔ dynamic
-
getter/setter pair
- deductionTime ↔ int?
-
getter/setter pair
- desc ↔ String?
-
getter/setter pair
- firstDeductionTime ↔ int?
-
getter/setter pair
- firstDeductionType ↔ int?
-
getter/setter pair
- firstPeriod ↔ dynamic
-
getter/setter pair
- firstPeriodType ↔ int?
-
getter/setter pair
- getPriceUrl ↔ dynamic
-
getter/setter pair
- gracePeriod ↔ dynamic
-
getter/setter pair
- group ↔ String?
-
getter/setter pair
- groupInfo ↔ dynamic
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
getter/setter pair
- imageUrl ↔ dynamic
-
getter/setter pair
- iosProductId ↔ String?
-
getter/setter pair
- operator ↔ String?
-
getter/setter pair
- ourReceiveAccount ↔ dynamic
-
getter/setter pair
- ourReceiveBank ↔ dynamic
-
getter/setter pair
- ourReceiveSubjectId ↔ dynamic
-
getter/setter pair
- paymentSchemes ↔ int?
-
getter/setter pair
- payType ↔ int?
-
getter/setter pair
- prdId ↔ String?
-
getter/setter pair
- prdMchMappingId ↔ dynamic
-
getter/setter pair
- prdName ↔ String?
-
getter/setter pair
- promotion ↔ String?
-
getter/setter pair
- remark ↔ dynamic
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkVersionShow ↔ dynamic
-
getter/setter pair
- shelveStatus ↔ int?
-
getter/setter pair
- signingRedirectUrl ↔ dynamic
-
getter/setter pair
- signType ↔ dynamic
-
getter/setter pair
- status ↔ int?
-
getter/setter pair
- storeEntity ↔ CommodityStoreEntity?
-
getter/setter pair
- timeliness ↔ int?
-
getter/setter pair
- type ↔ int?
-
getter/setter pair
- unitPrice ↔ double?
-
getter/setter pair
- utime ↔ String?
-
getter/setter pair
Methods
-
copyWith(
{dynamic gracePeriod, String? prdId, int? firstDeductionType, dynamic ourReceiveAccount, dynamic remark, int? type, String? operator, int? firstPeriodType, int? payType, dynamic sdkVersionShow, dynamic imageUrl, String? ctime, String? iosProductId, dynamic signType, int? id, dynamic groupInfo, int? shelveStatus, String? group, double? unitPrice, dynamic customParamInfoList, int? paymentSchemes, String? prdName, String? utime, int? deductionTime, int? firstDeductionTime, String? commodityId, dynamic signingRedirectUrl, dynamic firstPeriod, dynamic customParam, dynamic getPriceUrl, int? timeliness, String? commodityProperty, dynamic prdMchMappingId, dynamic ourReceiveBank, String? commodityDesc, dynamic ourReceiveSubjectId, String? commodityName, String? desc, int? status, String? promotion, CommodityStoreEntity? storeEntity}) → CommodityItemEntity -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited