DeviceInfoEntity class

Constructors

DeviceInfoEntity({String? identifier, int? buildVersionCode, String? name, String? versionString, String? versionCode, String? sysVersion, String? machine, String? idfv, int? screenWidth, int? screenHeight, String? adsToken})
DeviceInfoEntity.fromJson(dynamic json)

Properties

adsToken String?
Apple Ads 归因的 attributionToken
getter/setter pair
buildVersionCode int?
应用构建号(内部版本号),对应 iOS 的 CFBundleVersion
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identifier String?
应用包名(Bundle Identifier),如 com.xxx.app
getter/setter pair
idfv String?
设备 IDFV(Identifier For Vendor)
getter/setter pair
machine String?
设备型号标识,如 iPhone13,4
getter/setter pair
name String?
应用展示名称,对应 CFBundleDisplayName
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenHeight int?
屏幕高度(单位:pt)
getter/setter pair
screenWidth int?
屏幕宽度(单位:pt)
getter/setter pair
sysVersion String?
系统版本号,如 18.4.1
getter/setter pair
versionCode String?
应用版本号数值形式(去掉点号),如 1.0.0 -> "100"
getter/setter pair
versionString String?
应用版本号字符串,对应 CFBundleShortVersionString,如 1.0.0
getter/setter pair

Methods

copyWith({String? identifier, int? buildVersionCode, String? name, String? versionString, String? versionCode, String? sysVersion, String? machine, String? idfv, int? screenWidth, int? screenHeight, String? adsToken}) DeviceInfoEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited