- Inheritance
-
- Object
- PlatformInterface
- NnsdkPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
actionStartEnableBDA()
→ Future<void>
-
-
finishTransaction(String tid)
→ Future<void>
-
-
finishUnVerifyOrders(bool isDiscard, String identifier)
→ Future<PayResultEntity?>
-
-
getDeviceId()
→ Future<String>
-
-
getDeviceInfo()
→ Future<DeviceInfoEntity?>
-
-
getGDTId()
→ Future<Map<String, dynamic>?>
-
-
getNetworkType()
→ Future<String>
-
-
getSMIds()
→ Future<Map>
-
-
getString(String key)
→ Future<String?>
-
-
handleNativeCallFlutterEvent(dynamic data)
→ void
-
-
initAdSDK(String? prdId, bool isDebug, String? csjAdAppId, String? gdtAdAppId, String? ksAdAppId)
→ Future<void>
-
-
initGDT(String appId, String appKey)
→ Future<void>
-
-
mergeStoreProducts(List<Map> list)
→ Future<List<CommodityItemEntity>>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onListenStreamData()
→ void
-
-
restore(String userIdentifier)
→ Future<RestoreResultEntity>
-
-
saveString(String value, String key)
→ Future<void>
-
-
startPay(String iosProductId, String orderId, String uuid, String userIdentifier)
→ Future<PayResultEntity?>
-
-
toString()
→ String
-
A string representation of this object.
inherited