CommodityStoreEntity class
Constructors
- CommodityStoreEntity({String? subscriptionRoundUnit, int? subscriptionRoundValue, String? introductoryPaymentMode, String? introductoryRoundUnit, int? promotionalRoundValue, bool? isEligibleForIntroOffer, String? storeCurrency, bool? isEligiblePromotionalOffer, int? introductoryRoundValue, num? promotionalOfferPrice, num? storePrice, String? promotionalRoundUnit, num? introductoryOfferPrice})
- CommodityStoreEntity.fromJson(dynamic json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- introductoryOfferPrice ↔ num?
-
订阅首购/试用期间单价
getter/setter pair
- introductoryPaymentMode ↔ String?
-
订阅的试用/促销付款模式
getter/setter pair
- introductoryRoundUnit ↔ String?
-
订阅试用/促销周期单位
getter/setter pair
- introductoryRoundValue ↔ int?
-
订阅试用/促销周期数值
getter/setter pair
- isEligibleForIntroOffer ↔ bool?
-
当前用户是否符合订阅首购/试用优惠条件
getter/setter pair
- isEligiblePromotionalOffer ↔ bool?
-
当前用户是否符合促销优惠条件
getter/setter pair
- isFreeIntroTrial → bool
-
是否为免费试用(未使用过免费试用资格)
no setter
- isPayAsYouGoIntro → bool
-
是否为按期付款优惠(Pay As You Go)
no setter
- promotionalOfferPrice ↔ num?
-
促销期间单价
getter/setter pair
- promotionalRoundUnit ↔ String?
-
促销订阅周期单位
getter/setter pair
- promotionalRoundValue ↔ int?
-
促销订阅周期数值
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storeCurrency ↔ String?
-
商店价格币种,如
CNY、USDgetter/setter pair - storePrice ↔ num?
-
商店原价(未折扣单价)
getter/setter pair
- subscriptionRoundUnit ↔ String?
-
订阅周期单位
getter/setter pair
- subscriptionRoundValue ↔ int?
-
订阅周期数值
getter/setter pair
Methods
-
copyWith(
{String? subscriptionRoundUnit, int? subscriptionRoundValue, String? introductoryPaymentMode, String? introductoryRoundUnit, int? promotionalRoundValue, bool? isEligibleForIntroOffer, String? storeCurrency, bool? isEligiblePromotionalOffer, int? introductoryRoundValue, num? promotionalOfferPrice, num? storePrice, String? promotionalRoundUnit, num? introductoryOfferPrice}) → CommodityStoreEntity -
introductoryRoundUnitText(
) → String -
将
introductoryRoundUnit转换为中文描述 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
promotionalRoundUnitText(
) → String -
将
promotionalRoundUnit转换为中文描述 -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited