ConfigEntity class
Constructors
Properties
- csjAdAppId → String?
-
no setter
- encryptedHeader → bool
-
no setter
- gdtAdAppId → String?
-
no setter
- gdtAppId → String?
-
no setter
- gdtAppKey → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String?
-
no setter
- isDebug → bool?
-
no setter
- isLog → bool?
-
no setter
- ksAdAppId → String?
-
no setter
- prdId → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isDebug, bool? isLog, String? host}) → ConfigEntity -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited